@@ -21,12 +21,13 @@
  */
 
 #include <QtGui/QApplication>
-#include "mainwindow.h"
+#include "mainform.h"
 
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
-    MainWindow w;
+    MainForm w;
+
 #if defined(Q_WS_S60)
     w.showMaximized();
 #else
